Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(189)

Unified Diff: components/offline_pages/offline_page_model_impl.h

Issue 2342443006: [Offline pages] Use the new policy bits (Closed)
Patch Set: code review update Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/offline_pages/offline_page_model_impl.h
diff --git a/components/offline_pages/offline_page_model_impl.h b/components/offline_pages/offline_page_model_impl.h
index 521893111dadb3ccd1694dfcfdf25f215b43179c..50ed17b521b0124b889b3c7c6071d85489f10b74 100644
--- a/components/offline_pages/offline_page_model_impl.h
+++ b/components/offline_pages/offline_page_model_impl.h
@@ -258,8 +258,8 @@ class OfflinePageModelImpl : public OfflinePageModel, public KeyedService {
// Post task to clear storage.
void PostClearStorageIfNeededTask();
- // Check if |offline_page| is user-requested.
- bool IsUserRequestedPage(const OfflinePageItem& offline_page) const;
+ // Check if |offline_page| should be removed on cache reset by user.
+ bool IsRemovedOnCacheReset(const OfflinePageItem& offline_page) const;
void RunWhenLoaded(const base::Closure& job);

Powered by Google App Engine
This is Rietveld 408576698